/*-------------------------------------------------------------------------
 Copyright 2006 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.xolite.utils;


import java.io.IOException;

import net.sf.xolite.XMLSerializable;
import net.sf.xolite.XMLSerializeException;
import net.sf.xolite.impl.FlowXMLSerializer;


/**
 * XML serializer writing output to the java console. <br>
 * Just for debug, this serializer does not pay attention to encoding or or reserved characters.
 */
public class ConsoleXMLSerializer extends FlowXMLSerializer {


    public static void dump(XMLSerializable root) {
        try {
            if (root == null) System.out.println("[null]");
            else new ConsoleXMLSerializer().writeDocument(root);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    public void writeDocument(XMLSerializable root) throws XMLSerializeException {
        startDocument();
        root.serialize(this);
        endDocument();
    }


    protected void writeNewLine() throws IOException {
        System.out.println("");
    }


    protected void writeString(String text) throws IOException {
        System.out.print(text);
    }


    protected void writeDataCharacters(String text) throws IOException {
        System.out.print(text);
    }


    protected void writeCharacter(char ch) throws IOException {
        System.out.print(ch);
    }


}
